.. Django-admin-tools-stats documentation master file, created by
   sphinx-quickstart on Mon Apr 25 23:21:38 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Django Admin Tools Stats Documentation!
=======================================

:Release: |version|
:Date: |today|
:Keywords: django, python, plot, graph, nvd3, d3, dashboard
:Author: Arezqui Belaid, Petr Dlouhý
:Description: Django-admin-tools-stats is a Django admin module that allow you to create easily charts on your dashboard based on specific models and criterias.


Contents:

.. toctree::
    :maxdepth: 2

    introduction
    developer-doc


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
